##############
profiles
##############

.. toctree::
   :maxdepth: 1

   cmap
   dsig
   fvar
   gdef
   general
   glyf
   googlefonts
   gpos
   head
   hhea
   hmtx
   kern
   loca
   name
   opentype
   os2
   post
   shared_conditions
   ufo_sources


.. automodule:: fontbakery.profiles
   :members:
   :undoc-members:
